angle

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 15, 2026 License: GPL-3.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DegreesFromRadians

func DegreesFromRadians(radians float64) float64

DegreesFromRadians returns the angle in degrees which is given in radians. It will be in the range [0, 360)

func NormalizeDegrees

func NormalizeDegrees(degrees float64) float64

NormalizeDegrees resturns the normalized angle in degrees. It will be in the range [0, 360)

func NormalizeDegreesLatitude

func NormalizeDegreesLatitude(degrees float64) float64

NormalizeDegrees resturns the normalized angle in degrees. It will be in the range [-180, 180)

func NormalizeRadians

func NormalizeRadians(radians float64) float64

NormalizeRadians returns the normalized angle in radians. It will be in the range [0, 2π)

func NormalizeRadiansLatitude

func NormalizeRadiansLatitude(radians float64) float64

NormalizeRadiansLatitude returns the normalized angle in radians. It will be in the range [-π, π)

func RadiansFromDegrees

func RadiansFromDegrees(degrees float64) float64

RadiansFromDegrees returns the angle in radians which is given in degrees. It will be in the range [0, 2π)

Types

This section is empty.

Jump to