Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AltitudeArray ¶
type AltitudeArray [horizonAngleResolution]float64
func AltitudeFromBytes ¶
func AltitudeFromBytes(bytes []byte) (AltitudeArray, error)
AltitudeFromBytes returns an altitude array from a byte slice
type Horizon ¶
func NewHorizon ¶
NewHorizon returns the computed horizon for a given location. The computation starts at the given startRadius
func NewHorizonWithAltitude ¶
func NewHorizonWithAltitude(place *location.Location, r int, a AltitudeArray) *Horizon
NewHorizonWithAltitude returns a horizon with a given startRadius and altitude
func (*Horizon) AltitudeToBytes ¶
AltitudeToBytes returns the altitude array of a horizon into a byte slice
func (Horizon) GetAltitude ¶
GetHorizonAngleAt returns the altitude angle of the horizon of a given location at a given azimut angle.
func (Horizon) GetAltitudeArray ¶
func (hor Horizon) GetAltitudeArray() AltitudeArray
GetAltitudeArray returns the altitude array of the given horizon. Only use for testing!
func (Horizon) GetStartRadius ¶
GetStartRadius returns the start radius of the given horizon. Only use for testing!
Click to show internal directories.
Click to hide internal directories.