Documentation
¶
Index ¶
- func DegreesFromRadians(radians float64) float64
- func NormalizeDegrees(degrees float64) float64
- func NormalizeDegreesLatitude(degrees float64) float64
- func NormalizeRadians(radians float64) float64
- func NormalizeRadiansLatitude(radians float64) float64
- func RadiansFromDegrees(degrees float64) float64
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DegreesFromRadians ¶
DegreesFromRadians returns the angle in degrees which is given in radians. It will be in the range [0, 360)
func NormalizeDegrees ¶
NormalizeDegrees resturns the normalized angle in degrees. It will be in the range [0, 360)
func NormalizeDegreesLatitude ¶
NormalizeDegrees resturns the normalized angle in degrees. It will be in the range [-180, 180)
func NormalizeRadians ¶
NormalizeRadians returns the normalized angle in radians. It will be in the range [0, 2π)
func NormalizeRadiansLatitude ¶
NormalizeRadiansLatitude returns the normalized angle in radians. It will be in the range [-π, π)
func RadiansFromDegrees ¶
RadiansFromDegrees returns the angle in radians which is given in degrees. It will be in the range [0, 2π)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.